summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorUnicronNL <kim.sidney@gmail.com>2018-05-17 22:52:01 +0200
committerUnicronNL <kim.sidney@gmail.com>2018-05-17 22:52:01 +0200
commit80ec9b746124ca540faeac332131a7833a08b14c (patch)
treeaf5eb4664e13097b4607b30ef31bee2fdbe7661b /src
parent9535c4b1c1fb6613e2abacac38b7f3bbf80a9309 (diff)
downloadlibpam-radius-auth-80ec9b746124ca540faeac332131a7833a08b14c.tar.gz
libpam-radius-auth-80ec9b746124ca540faeac332131a7833a08b14c.zip
Do not include config file
Use vbash instead of bash Only change shell for priv user
Diffstat (limited to 'src')
-rw-r--r--src/radius_shell.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/radius_shell.c b/src/radius_shell.c
index 5da76dc..e7cffad 100644
--- a/src/radius_shell.c
+++ b/src/radius_shell.c
@@ -92,7 +92,7 @@ execit:
/*
* Eventually handle this program being linked or symlinked
* and that the shell is one of the shells in /etc/shells
* Expect it to be installed as /sbin/radius/bash, etc.
*/
shell = strrchr(args[0], '/');
if (!shell)
@@ -110,11 +110,11 @@ execit:
/* should really check this against /etc/shell */
snprintf(execshell, sizeof execshell, "/bin/%s", check);
#else
- check = "bash";
+ check = "vbash";
if (*args[0] == '-')
- shell = "-bash";
+ shell = "-vbash";
else
- shell = "bash";
+ shell = "vbash";
snprintf(execshell, sizeof execshell, "/bin/%s", check);
#endif
@@ -92,7 +92,7 @@ execit:
* Eventually handle this program being linked or symlinked
* and that the shell is one of the shells in /etc/shells
- * Expect it to be installed as /sbin/radius/bash, etc.
+ * Expect it to be installed as /sbin/radius/vbash, etc.
*/
shell = strrchr(args[0], '/');